package com.chinamobile.xxjs.dios.bcm.client.component;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.chinamobile.xxjs.dios.bcm.client.api.IClientLoginService;
import com.chinamobile.xxjs.dios.bcm.client.util.AppContext;
import com.chinamobile.xxjs.dios.bcm.client.util.ClientInfo;
import com.chinamobile.xxjs.dios.bcm.exception.CustomException;
import com.chinamobile.xxjs.dios.bcm.request.ClientAuthRequest;
import com.chinamobile.xxjs.dios.bcm.response.RestResponse;
import com.chinamobile.xxjs.dios.bcm.response.TokenResponse;
import javax.annotation.Resource;
import okhttp3.Request;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;

@AutoConfigureAfter({AppContext.class})
public class ClientTokenHandler {
  @Value("#{'${dios.ignored.clientToken}'.split(',')}")
  private String[] ignoredClientToken;
  
  @Value("${dios.client.loginUrl:/api/cdm/client/login}")
  private String clientLoginUrl;
  
  @Resource
  private ClientInfo clientInfo;
  
  private ObjectProvider<IClientLoginService> clientLoginService;
  
  private transient TokenResponse tokenResponse;
  
  public ClientTokenHandler(ObjectProvider<IClientLoginService> clientLoginService) {
    this.clientLoginService = clientLoginService;
  }
  
  public String getClientToken(Request request) {
    String path = request.url().uri().getPath();
    if (this.clientLoginUrl.equals(path))
      return null; 
    if (this.ignoredClientToken != null && this.ignoredClientToken.length > 0)
      for (String s : this.ignoredClientToken) {
        if (s.equals(path))
          return null; 
      }  
    return getToken();
  }
  
  private String getToken() {
    if (this.tokenResponse == null || this.tokenResponse.getAccessToken() == null || this.tokenResponse
      
      .getAccessToken().getExpires_at() < (System.currentTimeMillis() - 300000L))
      synchronized (com.chinamobile.xxjs.dios.bcm.client.component.ClientTokenHandler.class) {
        if (this.tokenResponse == null || this.tokenResponse.getAccessToken() == null || this.tokenResponse
          
          .getAccessToken().getExpires_at() < (System.currentTimeMillis() - 300000L)) {
          RestResponse<TokenResponse> result = ((IClientLoginService)this.clientLoginService.getIfAvailable()).clientLogin(new ClientAuthRequest(this.clientInfo.getAppId(), this.clientInfo.getAppSecret()));
          if (result.isSuccess())
            this.tokenResponse = (TokenResponse)result.getData(); 
        } 
      }  
    if (this.tokenResponse == null || this.tokenResponse.getAccessToken() == null || 
      StringUtils.isEmpty(this.tokenResponse.getAccessToken().getToken_value()))
      throw new CustomException("client认证失败"); 
    return "Bearer " + this.tokenResponse.getAccessToken().getToken_value();
  }
}
